GearTrain

Struct GearTrain 

pub struct GearTrain<'a, E: Copy + Debug> { /* private fields */ }
A gear train, a mechanism consisting of a two or more gears meshed together. As this device has only one degree of freedom, it propagates Commands given to its terminals as well as States.

Implementations

Source

impl<'a, E: Copy + Debug> GearTrain<'a, E>

pub const fn with_ratio_raw(ratio: f32) -> Self

Construct a GearTrain with the ratio as an f32.

pub const fn with_ratio(ratio: Quantity) -> Self

Construct a GearTrain with the ratio as a dimensionless Quantity.

pub const fn new<const N: usize>(teeth: [f32; N]) -> Self

Construct a GearTrain from an array of the numbers of teeth on each gear in the train.

pub fn get_terminal_1(&self) -> &'a RefCell<Terminal<'a, E>>

Get a reference to the side 1 terminal of the device where (side 1) * ratio = (side 2).

pub fn get_terminal_2(&self) -> &'a RefCell<Terminal<'a, E>>

Get a reference to the side 2 terminal of the device where (side 1) * ratio = (side 2).