PointerDereferencer

Struct PointerDereferencer 

pub struct PointerDereferencer<P> { /* private fields */ }
Updatable, Getter, Settable, and TimeGetter are passed through Box, Rc<RefCell<T>>, Arc<RwLock<T>>, and Arc<Mutex<T>>, but this cannot be done safely for references involving raw pointer dereferencing. This is a wrapper struct that provides this functionality for *mut T, *const RwLock<T>, and *const Mutex<T>. It’s constructor is unsafe fn, so this is considered sound.

Implementations

Source

impl<P> PointerDereferencer<P>

pub const unsafe fn new(pointer: P) -> Self

The constructor for PointerDereferencer. Although this constructor itself does not run any unsafe code, it is unsafe fn since this type inherently performs unsafe functions. See the type documentation for more information.

Although it is technically possible to construct a PointerDereferencer<P> where P is not a raw pointer, there is no valid reason to do so and the object would be entirely useless.

pub fn into_ptr(self) -> P

Returns the inner pointer that the wrapper contains by consuming it. Due to the fact that pointers are Copy, copy_ptr, which does not consume self and is const fn, is preferred in almost all cases however.

Source

impl<P: Clone> PointerDereferencer<P>

pub fn clone_ptr(&self) -> P

Clones and returns the inner pointer that the wrapper contains. Due to the fact that pointers are Copy, copy_ptr is nearly always preferred both for clarity and because it is const fn however.

Source

impl<P: Copy> PointerDereferencer<P>

pub const fn copy_ptr(&self) -> P

This function is be identical to clone_ptr when P: Copy. However, copy_ptr should be preferred where possible because, unlike clone_inner, it is const fn. It is also clearer that the clone is very light.

Source

impl<T> PointerDereferencer<*mut T>

These functions get a PointerDereferencer<*mut dyn Trait> from a PointerDereferencer<*mut T> where T: Trait. Because raw pointers are Copy, they only require &self and do not consume the original PointerDereferencer. Unfortunately T currently must be Sized due to language limitations.

pub const fn as_dyn_updatable<E: Clone + Debug>( &self, ) -> PointerDereferencer<*mut dyn Updatable<E> + '_>
where T: Updatable<E>,

pub const fn as_dyn_getter<U, E: Clone + Debug>( &self, ) -> PointerDereferencer<*mut dyn Getter<U, E> + '_>
where T: Getter<U, E>,

pub const fn as_dyn_settable<U, E: Clone + Debug>( &self, ) -> PointerDereferencer<*mut dyn Settable<U, E> + '_>
where T: Settable<U, E>,

pub const fn as_dyn_time_getter<E: Clone + Debug>( &self, ) -> PointerDereferencer<*mut dyn TimeGetter<E> + '_>
where T: TimeGetter<E>,

pub const fn as_dyn_chronology<U>( &self, ) -> PointerDereferencer<*mut dyn Chronology<U> + '_>
where T: Chronology<U>,

Source

impl<T> PointerDereferencer<*const RwLock<T>>

These functions get a PointerDereferencer<*const RwLock<dyn Trait>> from a PointerDereferencer<*const RwLock<T>> where T: Trait. Because raw pointers are Copy, they only require &self and do not consume the original PointerDereferencer. Unfortunately T currently must be Sized due to language limitations.

pub const fn as_dyn_updatable<E: Clone + Debug>( &self, ) -> PointerDereferencer<*const RwLock<dyn Updatable<E> + '_>>
where T: Updatable<E>,

pub const fn as_dyn_getter<U, E: Clone + Debug>( &self, ) -> PointerDereferencer<*const RwLock<dyn Getter<U, E> + '_>>
where T: Getter<U, E>,

pub const fn as_dyn_settable<U, E: Clone + Debug>( &self, ) -> PointerDereferencer<*const RwLock<dyn Settable<U, E> + '_>>
where T: Settable<U, E>,

pub const fn as_dyn_time_getter<E: Clone + Debug>( &self, ) -> PointerDereferencer<*const RwLock<dyn TimeGetter<E> + '_>>
where T: TimeGetter<E>,

Source

impl<T> PointerDereferencer<*const Mutex<T>>

These functions get a PointerDereferencer<*const Mutex<dyn Trait>> from a PointerDereferencer<*const Mutex<T>> where T: Trait. Because raw pointers are Copy, they only require &self and do not consume the original PointerDereferencer. Unfortunately T currently must be Sized due to language limitations.

pub const fn as_dyn_updatable<E: Clone + Debug>( &self, ) -> PointerDereferencer<*const Mutex<dyn Updatable<E> + '_>>
where T: Updatable<E>,

pub const fn as_dyn_getter<U, E: Clone + Debug>( &self, ) -> PointerDereferencer<*const Mutex<dyn Getter<U, E> + '_>>
where T: Getter<U, E>,

pub const fn as_dyn_settable<U, E: Clone + Debug>( &self, ) -> PointerDereferencer<*const Mutex<dyn Settable<U, E> + '_>>
where T: Settable<U, E>,

pub const fn as_dyn_time_getter<E: Clone + Debug>( &self, ) -> PointerDereferencer<*const Mutex<dyn TimeGetter<E> + '_>>
where T: TimeGetter<E>,

Source

impl<T> PointerDereferencer<*const T>

pub const fn as_dyn_chronology<U>( &self, ) -> PointerDereferencer<*const dyn Chronology<U> + '_>
where T: Chronology<U>,