PositionDerivativeDependentPIDKValues

Struct PositionDerivativeDependentPIDKValues 

pub struct PositionDerivativeDependentPIDKValues {
    pub position: PIDKValues,
    pub velocity: PIDKValues,
    pub acceleration: PIDKValues,
}
A set of PID k-values for controlling each position derivative.

Fields

position: PIDKValues

Use these k-values when controlling position.

velocity: PIDKValues

Use these k-values when controlling velocity.

acceleration: PIDKValues

Use these k-values when controlling acceleration.

Implementations

Source

impl PositionDerivativeDependentPIDKValues

pub const fn new( position: PIDKValues, velocity: PIDKValues, acceleration: PIDKValues, ) -> Self

pub const fn get_k_values( &self, position_derivative: PositionDerivative, ) -> PIDKValues

Get the k-values for a specific position derivative.

pub const fn evaluate( &self, position_derivative: PositionDerivative, error: f32, error_integral: f32, error_derivative: f32, ) -> f32

Calculate the control variable using the coefficients for a given position derivative given error, its integral, and its derivative.