Struct Terminal

pub struct Terminal<'a, E: Clone + Debug> { /* private fields */ }
A place where a device can connect to another.

Implementations

Source

impl<E: Clone + Debug> Terminal<'_, E>

pub const fn new_raw() -> Self

Direct constructor for a Terminal. You almost always actually want RefCell<Terminal> however, in which case you should call new, which returns RefCell<Terminal>.

pub const fn new() -> RefCell<Self>

This constructs a RefCell<Terminal>. This is almost always what you want, and what is needed for connecting terminals. If you do just want a Terminal, use new_raw instead.

pub fn disconnect(&mut self)

Disconnect this terminal and the one that it is connected to. You can connect terminals by calling the rrtk::connect function.