pub enum Command {
Position(f32),
Velocity(f32),
Acceleration(f32),
}Expand description
A command for a motor to perform: go to a position, run at a velocity, or accelerate at a rate.
Variants
Position(f32)
Where you want to be. This should be in millimeters.
Velocity(f32)
How fast you want to be going. This should be in millimeters per second.
Acceleration(f32)
How fast you want how fast you’re going to change. This should be in millimeters per second squared.
Implementations
Sourceimpl Command
impl Command
Sourcepub const fn new(position_derivative: PositionDerivative, value: f32) -> Self
pub const fn new(position_derivative: PositionDerivative, value: f32) -> Self
Constructor for Command.
Sourcepub fn get_position(&self) -> Option<Quantity>
pub fn get_position(&self) -> Option<Quantity>
Get the commanded constant position if there is one. If the position derivative is
velocity or acceleration, this will return None as there is not a constant position.
Sourcepub fn get_velocity(&self) -> Option<Quantity>
pub fn get_velocity(&self) -> Option<Quantity>
Get the commanded constant velocity if there is one. If the position derivative is
acceleration, this will return None as there is not a constant
velocity. If the position derivative is position, this will return 0 as
velocity should be zero with a constant position.
Sourcepub fn get_acceleration(&self) -> Quantity
pub fn get_acceleration(&self) -> Quantity
Get the commanded constant acceleration. If the position derivative is not acceleration, this will return 0 as acceleration should be zero with a constant velocity or position.