static_rw_lock_reference

Macro static_rw_lock_reference 

macro_rules! static_rw_lock_reference {
    ($type_: ty, $was: expr) => { ... };
}
Create a static RwLock of something and return a PtrRwLock-variant Reference to it.

The documentation shows rrtk::static_rw_lock_reference and rrtk::reference::static_rw_lock_reference separately. These are the same macro exported in two different places. These paths point to the same code in RRTK. Rust’s scoping rules for macros are a bit odd, but you should be able to use rrtk::static_rw_lock_reference and rrtk::reference::static_rw_lock_reference interchangably.