pub struct CommandPID<G: Getter<State, E> + ?Sized, E: Copy + Debug> { /* private fields */ }Expand description
Automatically integrates the command variable of a PID controller based on the position
derivative of a Command. Designed to make it easier to use a standard DC motor and an encoder
as a de facto servo.
Implementations
Sourceimpl<G: Getter<State, E> + ?Sized, E: Copy + Debug> CommandPID<G, E>
impl<G: Getter<State, E> + ?Sized, E: Copy + Debug> CommandPID<G, E>
Sourcepub const fn new(
input: Reference<G>,
command: Command,
kvalues: PositionDerivativeDependentPIDKValues,
) -> Self
pub const fn new( input: Reference<G>, command: Command, kvalues: PositionDerivativeDependentPIDKValues, ) -> Self
Constructor for CommandPID.
Sourcepub fn reset(&mut self)
pub fn reset(&mut self)
Clear cached data for calculating integral and derivative. After this is called, the PID controller will use the next few updates to rebuild its cache in the same way as it does during the first few updates after initialization. This is called when the command changes so as not to cause issues with the integral and derivative.