pub struct Terminal<'a, E: Clone + Debug> { /* private fields */ }Expand description
A place where a device can connect to another.
Implementations
Sourceimpl<E: Clone + Debug> Terminal<'_, E>
impl<E: Clone + Debug> Terminal<'_, E>
Sourcepub const fn new_raw() -> Self
pub const fn new_raw() -> Self
Direct constructor for a Terminal. You almost always actually want RefCell<Terminal>
however, in which case you should call new, which returns RefCell<Terminal>.
Sourcepub const fn new() -> RefCell<Self>
pub const fn new() -> RefCell<Self>
This constructs a RefCell<Terminal>. This is almost always what you want, and what is
needed for connecting terminals. If you do just want a Terminal, use
new_raw instead.
Sourcepub fn disconnect(&mut self)
pub fn disconnect(&mut self)
Disconnect this terminal and the one that it is connected to. You can connect terminals by
calling the rrtk::connect function.